INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES
('core_main_quickcreate_album', 'album', 'Add New Photos', 'Album_Plugin_Menus::canCreateAlbums', '{"route":"album_general","action":"upload","icon":"fi fi-rr-picture"}', 'core_main_quickcreate', '', 1);
DELETE FROM engine4_album_categories WHERE `engine4_album_categories`.`category_id` = 0;

UPDATE `engine4_core_menuitems` SET `params` = '{"route":"album_general","action":"browse","icon":"fi fi-rr-picture"}' WHERE `engine4_core_menuitems`.`name` = 'core_main_album';

UPDATE `engine4_core_menuitems` SET `description` = 'Create collections, share moments and engage members visually' WHERE `engine4_core_menuitems`.`name` = 'core_main_album';