ALTER TABLE `engine4_album_albums` ADD `location` VARCHAR(255) NULL DEFAULT NULL;
ALTER TABLE `engine4_album_photos` ADD `feedupload` TINYINT(1) NOT NULL DEFAULT '0';

DROP TABLE IF EXISTS `engine4_album_ratings`;
